/* GAUSS code
   File: NewLCTY0310.g 
   Coded by: Zheng-Feng Guo
   
   Local constant estimation of Tschernig-Yang (2000, JTSA) method.
   
References:
Guo, Z.-F. and Shintani, M. (2011).
  Nonparametric lag selection for nonlinear additive autoregressive models.
  Economics Letters, 111(2), 131-134.
  DOI: 10.1016/j.econlet.2011.01.014  
  
Guo, Z.-F., Cao, L.Y., and He, Y. (2011).
  Nonparametric lag selection for additive models based on the smooth
  backfitting estimator.
  Theoretical Economics Letters, 1, 15-17.
  
   
*/   

/* 
** ----------------------------------------------------------
** lag selection criteria for additive models
** ----------------------------------------------------------
*/
new;
cls;
clear all;
outwidth 132;
output file =NewLCTYLAR1.out reset;
itr = {100}; /* number of replications =itr */
rndseed 9999;   
para1=1;
para2=2;
@h={0.2,0.4,0.6,0.8,1,1.2,1.4,1.6,1.8,2};@
@h={0.1,0.4,0.6,0.8,1,4,6,8,10,20,40};@
h={0.2,0.6,0.8,1,1.4,1.8,2};
@h={0.2,0.6,1,1.4,1.8,2.2,2.6,3.0,3.4,3.8,4.0};@
@h={1,1.2,1.4,1.6,1.8,2};@
nc=rows(h);
T=100;
AFPE=zeros(itr,6);
GAhat1 = zeros(itr,nc);
GAhat2 = zeros(itr,nc);
GAhat3 = zeros(itr,nc);
GAhat4 = zeros(itr,nc);
GAhat5 = zeros(itr,nc);
GAhat6 = zeros(itr,nc);
GAhat7 = zeros(itr,nc);
GAhat8 = zeros(itr,nc);
GAhat9 = zeros(itr,nc);
GAhat10 = zeros(itr,nc);
GAhat11 = zeros(itr,nc);
GAhat12 = zeros(itr,nc);
GAhat13 = zeros(itr,nc);
GBhat1 = zeros(itr,nc);
GBhat2 = zeros(itr,nc);
GBhat3 = zeros(itr,nc);
GBhat4 = zeros(itr,nc);
GBhat5 = zeros(itr,nc);
GBhat6 = zeros(itr,nc);
GBhat7 = zeros(itr,nc);
GBhat8 = zeros(itr,nc);
GBhat9 = zeros(itr,nc);
GBhat10 = zeros(itr,nc);
GBhat11 = zeros(itr,nc);
GBhat12 = zeros(itr,nc);
GBhat13 = zeros(itr,nc);
GFPE1 = zeros(itr,nc);
GFPE2 = zeros(itr,nc);
GFPE3 = zeros(itr,nc);
GFPE4 = zeros(itr,nc);
GFPE5 = zeros(itr,nc);
GFPE6 = zeros(itr,nc);
GFPE7 = zeros(itr,nc);
GFPE8 = zeros(itr,nc);
GFPE9 = zeros(itr,nc);
GFPE10 = zeros(itr,nc);
GFPE11 = zeros(itr,nc);
GFPE12 = zeros(itr,nc);
GFPE13 = zeros(itr,nc);
epsln = 1e-60; /* double precision factor */
tstart = time;
tvec = { 3600 60 1 0 };
lag=zeros(itr,6);
tt = tvec*tstart;
/*********************************************/
/* (0) Simulation design                     */
/*********************************************/
tstart = time;
tvec = { 3600 60 1 0 };
tt = tvec*tstart;
output on;
screen on;
k = 1;
do until k > itr;
/*********************************************/
/* (1) Iteration starts here                 */
/*********************************************/
        e = 0.1*rndn(T+33,1);
        f=zeros(T+33,1);
        f[1] = rndn(1,1);
        f[2]=rndn(1,1);
/*Linear processes AR1 */
        j = 3;
         do until j > T+33;
        f[j] = 0.5*f[j-1]+0.4*f[j-2] +e[j];
        j = j + 1;
         endo;
/*Linear processes AR2
        j = 3;
         do until j > T+33;
        f[j] =-0.5*f[j-1]+0.4*f[j-2] +e[j];
        j = j + 1;
         endo;*/
/*Linear processes AR3
        f[3] = rndn(1,1);
        f[4]=rndn(1,1);
        f[5] = rndn(1,1);
        f[6]=rndn(1,1);
        f[7] = rndn(1,1);
        f[8]=rndn(1,1);
        f[9] = rndn(1,1);
        f[10]=rndn(1,1);
        j = 11;
         do until j > T+33;
        f[j] = -0.5*f[j-6]+0.5*f[j-10] +e[j];
        j = j + 1;
         endo; */
       /*LAR4 
        f[1] = rndn(1,1);
        f[2]=rndn(1,1);
        f[3] =rndn(1,1);
        f[4]=rndn(1,1);
        j = 5;
        do until j > T+23;
        f[j] = -0.8*f[j-1]-0.4*f[j-2]+0.25*f[j-3]+e[j];
        j = j + 1;
        endo;*/
 /*nonlinear processes NLAR1 
         j=3;
         do until j > T+23;
               f[j] =-0.4*(3-f[j-1]^2)/(1+f[j-1]^2)+0.6*(3-(f[j-2]-0.5)^3)/(1+(f[j-2]-0.5)^4)+ e[j];
                j = j + 1;
         endo;*/ 

 /*nonlinear processes NLAR2   
        f[3]=rndn(1,1);
        f[4]=rndn(1,1);
        f[5]=rndn(1,1);
        f[6]=rndn(1,1);
        f[7]=rndn(1,1);
        f[8]=rndn(1,1);
        f[9]=rndn(1,1);
        f[10]=rndn(1,1);
        j = 11;
         do until j > T+33;
        f[j] = (0.4-2*exp(-50*f[j-6]^2))*f[j-6]+ (0.5-0.5*exp(-50*f[j-10]^2))*f[j-10]+e[j];
        j = j + 1;
         endo;*/

  /*nonlinear processes NLAR3   
        f[3]=rndn(1,1);
        f[4]=rndn(1,1);
        f[5]=rndn(1,1);
        f[6]=rndn(1,1);
        f[7]=rndn(1,1);
        f[8]=rndn(1,1);
        f[9]=rndn(1,1);
        f[10]=rndn(1,1);
        j = 11;
         do until j > T+33;
        f[j] = (0.4-2*cos(40*f[j-6])*exp(-30*f[j-6]^2))*f[j-6]+ (0.55-0.55*sin(40*f[j-10])*exp(-10*f[j-10]^2))*f[j-10]+e[j];
        j = j + 1;
         endo;*/
         f = trimr(f,20,0);
         x0 = trimr(f,13,0); /* dependent variable x(t) */
         x1 = trimr(f,12,1);/* dependent variable x(t-1) */
         x2 = trimr(f,11,2);/* dependent variable x(t-2) */
         x3 = trimr(f,10,3);/* dependent variable x(t-3) */
         x4 = trimr(f,9,4);/* dependent variable x(t-4) */
         x5 = trimr(f,8,5);/* dependent variable x(t-5) */
         x6=  trimr(f,7,6);/* dependent variable x(t-6) */
         x7 = trimr(f,6,7); /* dependent variable x(t-7) */
         x8 = trimr(f,5,8);/* dependent variable x(t-8) */
         x9 = trimr(f,4,9);/* dependent variable x(t-9) */
         x10 = trimr(f,3,10);/* dependent variable x(t-10) */
         x11 = trimr(f,2,11);/* dependent variable x(t-11) */
         x12 = trimr(f,1,12);/* dependent variable x(t-12) */
         x13=  trimr(f,0,13);/* dependent variable x(t-13) */
         xx=x1~x2~x3~x4~x5~x6~x7~x8~x9~x10~x11~x12~x13;
         y=x0;
         data=xx;
         sey=stdc(y);
/*bandwidth by rule of thumb */
 hs1=sey*(4/3)^(1/5)*T^(-1/5);
 hs2=sey*(4/4)^(1/6)*T^(-1/6);
 hs3=sey*(4/5)^(1/7)*T^(-1/7);
 hs4=sey*(4/6)^(1/8)*T^(-1/8);
 hs5=sey*(4/7)^(1/9)*T^(-1/9);
 hs6=sey*(4/8)^(1/10)*T^(-1/10);


/****************************One Lag Included ******************************************/

/* first lag The bandwith for B part in FPE by Tschernig and Yang called GFPE(general FPE) */      
        
/****************************One Lag Included Estimation of B part *******************************************/
      
i=1;
Bm0=zeros(T,13);
Gphat=zeros(T,13);
do until i>T;
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u1i;
xx02 = ones(T,1)~u2i ;
xx03 = ones(T,1)~u3i;
xx04 = ones(T,1)~u4i;
xx05 = ones(T,1)~u5i;
xx06 = ones(T,1)~u6i;
xx07 = ones(T,1)~u7i;
xx08 = ones(T,1)~u8i;
xx09 = ones(T,1)~u9i;
xx10 = ones(T,1)~u10i;
xx11 = ones(T,1)~u11i;
xx12 = ones(T,1)~u12i;
xx13 = ones(T,1)~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
/*weight for GLS in conditional mean*/
     w1 = fi(u1i/hs1); 
     w2 = fi(u2i/hs1); 
     w3 = fi(u3i/hs1);  
     w4 = fi(u4i/hs1);
     w5 = fi(u5i/hs1);
     w6 = fi(u6i/hs1); 
     w7 = fi(u7i/hs1);  
     w8 = fi(u8i/hs1);  
     w9 = fi(u9i/hs1);
     w10 = fi(u10i/hs1);
     w11 = fi(u11i/hs1); 
     w12 = fi(u12i/hs1); 
     w13 = fi(u13i/hs1);
     w1[i]=0;
     w2[i]=0;
     w3[i]=0;
     w4[i]=0;
     w5[i]=0;
     w6[i]=0;
     w7[i]=0;
     w8[i]=0;
     w9[i]=0;
     w10[i]=0;
     w11[i]=0;
     w12[i]=0;
     w13[i]=0;
     wmat1 =diagrv((eye(T),w1));
     wmat2 =diagrv((eye(T),w2));
     wmat3 =diagrv((eye(T),w3));
     wmat4 =diagrv((eye(T),w4));
     wmat5 =diagrv((eye(T),w5));
     wmat6= diagrv((eye(T),w6));
     wmat7 =diagrv((eye(T),w7));
     wmat8 =diagrv((eye(T),w8));
     wmat9 =diagrv((eye(T),w9));
     wmat10 =diagrv((eye(T),w10));
     wmat11= diagrv((eye(T),w11));
     wmat12 =diagrv((eye(T),w12));
     wmat13= diagrv((eye(T),w13));

if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 Bm0[i,1] = a[1] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 Bm0[i,2] = a[1,.] ;
endif;

if det(xx03'wmat3*xx03) > epsln ;
 a3= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 Bm0[i,3] = a3[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a4= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 Bm0[i,4] = a4[1,.] ;
endif;  

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 Bm0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a6= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 Bm0[i,6] = a6[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 Bm0[i,7] = a[1,.] ;
endif;

if det(xx08'wmat8*xx08) > epsln ;
 a= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 Bm0[i,8] = a[1,.] ;
endif;

if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 Bm0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 Bm0[i,10] = a[1,.] ;
endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 Bm0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 Bm0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 Bm0[i,13] = a[1,.] ;
endif;
/*kernel estimator of the density function*/
 LVO= ones(T,1);
 LVO[i]=0;
  Gphat[i,1]=sumc(LVO.*fi(u1i/hs1))/((T-1)*hs1);
  Gphat[i,2]=sumc(LVO.*fi(u2i/hs1))/((T-1)*hs1);
  Gphat[i,3]=sumc(LVO.*fi(u3i/hs1))/((T-1)*hs1);
  Gphat[i,4]=sumc(LVO.*fi(u4i/hs1))/((T-1)*hs1);
  Gphat[i,5]=sumc(LVO.*fi(u5i/hs1))/((T-1)*hs1);
  Gphat[i,6]=sumc(LVO.*fi(u6i/hs1))/((T-1)*hs1);
  Gphat[i,7]=sumc(LVO.*fi(u7i/hs1))/((T-1)*hs1);
  Gphat[i,8]=sumc(LVO.*fi(u8i/hs1))/((T-1)*hs1);
  Gphat[i,9]=sumc(LVO.*fi(u9i/hs1))/((T-1)*hs1);
  Gphat[i,10]=sumc(LVO.*fi(u10i/hs1))/((T-1)*hs1);
  Gphat[i,11]=sumc(LVO.*fi(u11i/hs1))/((T-1)*hs1);
  Gphat[i,12]=sumc(LVO.*fi(u12i/hs1))/((T-1)*hs1);
  Gphat[i,13]=sumc(LVO.*fi(u13i/hs1))/((T-1)*hs1);
i=i+1;
endo;
BR1=(Bm0[.,1]-y).*(Bm0[.,1]-y);
BR2=(Bm0[.,2]-y).*(Bm0[.,2]-y);
BR3=(Bm0[.,3]-y).*(Bm0[.,3]-y);
BR4=(Bm0[.,4]-y).*(Bm0[.,4]-y);
BR5=(Bm0[.,5]-y).*(Bm0[.,5]-y);
BR6=(Bm0[.,6]-y).*(Bm0[.,6]-y);
BR7=(Bm0[.,7]-y).*(Bm0[.,7]-y);
BR8=(Bm0[.,8]-y).*(Bm0[.,8]-y);
BR9=(Bm0[.,9]-y).*(Bm0[.,9]-y);
BR10=(Bm0[.,10]-y).*(Bm0[.,10]-y);
BR11=(Bm0[.,11]-y).*(Bm0[.,11]-y);
BR12=(Bm0[.,12]-y).*(Bm0[.,12]-y);
BR13=(Bm0[.,13]-y).*(Bm0[.,13]-y);
quan=quantile(Gphat,0.05);
index=Gphat.<=quan;
Gphat=index*10^5+Gphat;

/****************************One Lag Included Estimation of A part *******************************************/

/*Esitimation of A part one lag is included */
kc=1;
do until kc>nc;
i=1;
ha1=hs1*h[kc,1];
m0=zeros(T,13);
do until i>T;
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u1i;
xx02 = ones(T,1)~u2i ;
xx03 = ones(T,1)~u3i;
xx04 = ones(T,1)~u4i;
xx05 = ones(T,1)~u5i;
xx06 = ones(T,1)~u6i;
xx07 = ones(T,1)~u7i;
xx08 = ones(T,1)~u8i;
xx09 = ones(T,1)~u9i;
xx10 = ones(T,1)~u10i;
xx11 = ones(T,1)~u11i;
xx12 = ones(T,1)~u12i;
xx13 = ones(T,1)~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);

/*weight for GLS in conditional mean*/
     w1 = fi(u1i/ha1); 
     w2 = fi(u2i/ha1);
     w3 = fi(u3i/ha1);
     w4 = fi(u4i/ha1);
     w5 = fi(u5i/ha1);
     w6 = fi(u6i/ha1);
     w7 = fi(u7i/ha1); 
     w8 = fi(u8i/ha1);
     w9 = fi(u9i/ha1);
     w10 = fi(u10i/ha1);
     w11 = fi(u11i/ha1);
     w12 = fi(u12i/ha1);
     w13 = fi(u13i/ha1);
     wmat1 =diagrv((eye(T),w1));
     wmat2 =diagrv((eye(T),w2));
     wmat3 =diagrv((eye(T),w3));
     wmat4 =diagrv((eye(T),w4));
     wmat5 =diagrv((eye(T),w5));
     wmat6= diagrv((eye(T),w6));
     wmat7 =diagrv((eye(T),w7));
     wmat8 =diagrv((eye(T),w8));
     wmat9 =diagrv((eye(T),w9));
     wmat10 =diagrv((eye(T),w10));
     wmat11= diagrv((eye(T),w11));
     wmat12 =diagrv((eye(T),w12));
     wmat13= diagrv((eye(T),w13));

 if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 m0[i,1] = a[1] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 m0[i,2] = a[1,.] ;
endif;

if det(xx03'wmat3*xx03) > epsln ;
 a3= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 m0[i,3] = a3[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a4= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 m0[i,4] = a4[1,.] ;
endif;  

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 m0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a6= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 m0[i,6] = a6[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 m0[i,7] = a[1,.] ;
endif;

if det(xx08'wmat8*xx08) > epsln ;
 a= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 m0[i,8] = a[1,.] ;
endif;

if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 m0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 m0[i,10] = a[1,.] ;
endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 m0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 m0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 m0[i,13] = a[1,.] ;
endif;
i=i+1;
endo;

/* FPE by Tschernig and Yang called GFPE(general FPE)*/
R1=(m0[.,1]-y).*(m0[.,1]-y);
R2=(m0[.,2]-y).*(m0[.,2]-y);
R3=(m0[.,3]-y).*(m0[.,3]-y);
R4=(m0[.,4]-y).*(m0[.,4]-y);
R5=(m0[.,5]-y).*(m0[.,5]-y);
R6=(m0[.,6]-y).*(m0[.,6]-y);
R7=(m0[.,7]-y).*(m0[.,7]-y);
R8=(m0[.,8]-y).*(m0[.,8]-y);
R9=(m0[.,9]-y).*(m0[.,9]-y);
R10=(m0[.,10]-y).*(m0[.,10]-y);
R11=(m0[.,11]-y).*(m0[.,11]-y);
R12=(m0[.,12]-y).*(m0[.,12]-y);
R13=(m0[.,13]-y).*(m0[.,13]-y);
GAhat1[k,kc]= 1/T*sumc(R1);
GAhat2[k,kc]= 1/T*sumc(R2);
GAhat3[k,kc]= 1/T*sumc(R3);
GAhat4[k,kc]= 1/T*sumc(R4);
GAhat5[k,kc]= 1/T*sumc(R5);
GAhat6[k,kc]= 1/T*sumc(R6);
GAhat7[k,kc]= 1/T*sumc(R7);
GAhat8[k,kc]= 1/T*sumc(R8);
GAhat9[k,kc]= 1/T*sumc(R9);
GAhat10[k,kc]= 1/T*sumc(R10);
GAhat11[k,kc]= 1/T*sumc(R11);
GAhat12[k,kc]= 1/T*sumc(R12);
GAhat13[k,kc]= 1/T*sumc(R13);
GBhat1[k,kc] =2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR1./Gphat[.,1])*1/T;
GBhat2[k,kc] =2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR2./Gphat[.,2])*1/T;
GBhat3[k,kc] =2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR3./Gphat[.,3])*1/T;
GBhat4[k,kc] =2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR4./Gphat[.,4])*1/T;
GBhat5[k,kc] =2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR5./Gphat[.,5])*1/T;
GBhat6[k,kc] =2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR6./Gphat[.,6])*1/T;
GBhat7[k,kc] =2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR7./Gphat[.,7])*1/T;
GBhat8[k,kc] =2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR8./Gphat[.,8])*1/T;
GBhat9[k,kc] =2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR9./Gphat[.,9])*1/T;
GBhat10[k,kc]=2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR10./Gphat[.,10])*1/T;
GBhat11[k,kc]=2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR11./Gphat[.,11])*1/T;
GBhat12[k,kc]=2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR12./Gphat[.,12])*1/T;
GBhat13[k,kc]=2/(ha1)*1/sqrt(2*pi)*1/T*sumc(BR13./Gphat[.,13])*1/T;
GFPE1[k,kc]=GAhat1[k,kc]+GBhat1[k,kc];
GFPE2[k,kc]=GAhat2[k,kc]+GBhat2[k,kc];
GFPE3[k,kc]=GAhat3[k,kc]+GBhat3[k,kc];
GFPE4[k,kc]=GAhat4[k,kc]+GBhat4[k,kc];
GFPE5[k,kc]=GAhat5[k,kc]+GBhat5[k,kc];
GFPE6[k,kc]=GAhat6[k,kc]+GBhat6[k,kc];
GFPE7[k,kc]=GAhat7[k,kc]+GBhat7[k,kc];
GFPE8[k,kc]=GAhat8[k,kc]+GBhat8[k,kc];
GFPE9[k,kc]=GAhat9[k,kc]+GBhat9[k,kc];
GFPE10[k,kc]=GAhat10[k,kc]+GBhat10[k,kc];
GFPE11[k,kc]=GAhat11[k,kc]+GBhat11[k,kc];
GFPE12[k,kc]=GAhat12[k,kc]+GBhat12[k,kc];
GFPE13[k,kc]=GAhat13[k,kc]+GBhat13[k,kc];

kc=kc+1;
endo;
min1=minc(GFPE1[k,.]');
min2=minc(GFPE2[k,.]');
min3=minc(GFPE3[k,.]');
min4=minc(GFPE4[k,.]');
min5=minc(GFPE5[k,.]');
min6=minc(GFPE6[k,.]');
min7=minc(GFPE7[k,.]');
min8=minc(GFPE8[k,.]');
min9=minc(GFPE9[k,.]');
min10=minc(GFPE10[k,.]');
min11=minc(GFPE11[k,.]');
min12=minc(GFPE12[k,.]');
min13=minc(GFPE13[k,.]');
minGFPE=min1~min2~min3~min4~min5~min6~min7~min8~min9~min10~min11~min12~min13;
lag[k,1]=minindc(minGFPE');
AFPE[k,1]=minc(minGFPE');
lag_1=lag[k,1];

/****************************Two Lag Included *******************************************/

/****************************Two Lag Included Estimation of B part *******************************************/
i=1;
Bm0=zeros(T,13);
Gphat=zeros(T,13);
do until i>T;
u0i=data[i,lag_1]*ones(T,1) - data[.,lag_1];
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u0i~u1i;
xx02 = ones(T,1)~u0i~u2i ;
xx03 = ones(T,1)~u0i~u3i;
xx04 = ones(T,1)~u0i~u4i;
xx05 = ones(T,1)~u0i~u5i;
xx06 = ones(T,1)~u0i~u6i;
xx07 = ones(T,1)~u0i~u7i;
xx08 = ones(T,1)~u0i~u8i;
xx09 = ones(T,1)~u0i~u9i;
xx10 = ones(T,1)~u0i~u10i;
xx11 = ones(T,1)~u0i~u11i;
xx12 = ones(T,1)~u0i~u12i;
xx13 = ones(T,1)~u0i~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
/*weight for GLS in conditional mean*/
w1 = fi(u0i/hs2).*fi(u1i/hs2);
w2 = fi(u0i/hs2).*fi(u2i/hs2);
w3 = fi(u0i/hs2).*fi(u3i/hs2);
w4 = fi(u0i/hs2).*fi(u4i/hs2);
w5 = fi(u0i/hs2).*fi(u5i/hs2);
w6 = fi(u0i/hs2).*fi(u6i/hs2);
w7 = fi(u0i/hs2).*fi(u7i/hs2);
w8 = fi(u0i/hs2).*fi(u8i/hs2);
w9 = fi(u0i/hs2).*fi(u9i/hs2);
w10 = fi(u0i/hs2).*fi(u10i/hs2);
w11 = fi(u0i/hs2).*fi(u11i/hs2);
w12 = fi(u0i/hs2).*fi(u12i/hs2);
w13 = fi(u0i/hs2).*fi(u13i/hs2);
w1[i]=0;
w2[i]=0;
w3[i]=0;
w4[i]=0;
w5[i]=0;
w6[i]=0;
w7[i]=0;
w8[i]=0;
w9[i]=0;
w10[i]=0;
w11[i]=0;
w12[i]=0;
w13[i]=0;
wmat1 =diagrv((eye(T),w1)) ;
wmat2 =diagrv((eye(T),w2)) ;
wmat3 =diagrv((eye(T),w3)) ;
wmat4 =diagrv((eye(T),w4)) ;
wmat5=diagrv((eye(T),w5)) ;
wmat6 =diagrv((eye(T),w6)) ;
wmat7 =diagrv((eye(T),w7)) ;
wmat8 =diagrv((eye(T),w8)) ;
wmat9 =diagrv((eye(T),w9)) ;
wmat10 =diagrv((eye(T),w10)) ;
wmat11=diagrv((eye(T),w11)) ;
wmat12 =diagrv((eye(T),w12)) ;
wmat13 =diagrv((eye(T),w13)) ;


if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 Bm0[i,1] = a[1] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 Bm0[i,2] = a[1,.] ;
endif;

xx03 = xx03;
if det(xx03'wmat3*xx03) > epsln ;
 a3= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 Bm0[i,3] = a3[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a4= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 Bm0[i,4] = a4[1,.] ;
endif;  

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 Bm0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a6= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 Bm0[i,6] = a6[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 Bm0[i,7] = a[1,.] ;
endif;

if det(xx08'wmat8*xx08) > epsln ;
 a= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 Bm0[i,8] = a[1,.] ;
endif;


if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 Bm0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 Bm0[i,10] = a[1,.] ;
endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 Bm0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 Bm0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 Bm0[i,13] = a[1,.] ;
endif;
/*kernel estimator of the density function leave-one-out */
 LVO= ones(T,1);
 LVO[i]=0;
Gphat[i,1]=sumc(LVO.*fi(u0i/hs2).*fi(u1i/hs2))/((T-1)*hs2^2);
Gphat[i,2]=sumc(LVO.*fi(u0i/hs2).*fi(u2i/hs2))/((T-1)*hs2^2);
Gphat[i,3]=sumc(LVO.*fi(u0i/hs2).*fi(u3i/hs2))/((T-1)*hs2^2);
Gphat[i,4]=sumc(LVO.*fi(u0i/hs2).*fi(u4i/hs2))/((T-1)*hs2^2);
Gphat[i,5]=sumc(LVO.*fi(u0i/hs2).*fi(u5i/hs2))/((T-1)*hs2^2);
Gphat[i,6]=sumc(LVO.*fi(u0i/hs2).*fi(u6i/hs2))/((T-1)*hs2^2);
Gphat[i,7]=sumc(LVO.*fi(u0i/hs2).*fi(u7i/hs2))/((T-1)*hs2^2);
Gphat[i,8]=sumc(LVO.*fi(u0i/hs2).*fi(u8i/hs2))/((T-1)*hs2^2);
Gphat[i,9]=sumc(LVO.*fi(u0i/hs2).*fi(u9i/hs2))/((T-1)*hs2^2);
Gphat[i,10]=sumc(LVO.*fi(u0i/hs2).*fi(u10i/hs2))/((T-1)*hs2^2);
Gphat[i,11]=sumc(LVO.*fi(u0i/hs2).*fi(u11i/hs2))/((T-1)*hs2^2);
Gphat[i,12]=sumc(LVO.*fi(u0i/hs2).*fi(u12i/hs2))/((T-1)*hs2^2);
Gphat[i,13]=sumc(LVO.*fi(u0i/hs2).*fi(u13i/hs2))/((T-1)*hs2^2);
i=i+1;
endo;
BR1=(Bm0[.,1]-y).*(Bm0[.,1]-y);
BR2=(Bm0[.,2]-y).*(Bm0[.,2]-y);
BR3=(Bm0[.,3]-y).*(Bm0[.,3]-y);
BR4=(Bm0[.,4]-y).*(Bm0[.,4]-y);
BR5=(Bm0[.,5]-y).*(Bm0[.,5]-y);
BR6=(Bm0[.,6]-y).*(Bm0[.,6]-y);
BR7=(Bm0[.,7]-y).*(Bm0[.,7]-y);
BR8=(Bm0[.,8]-y).*(Bm0[.,8]-y);
BR9=(Bm0[.,9]-y).*(Bm0[.,9]-y);
BR10=(Bm0[.,10]-y).*(Bm0[.,10]-y);
BR11=(Bm0[.,11]-y).*(Bm0[.,11]-y);
BR12=(Bm0[.,12]-y).*(Bm0[.,12]-y);
BR13=(Bm0[.,13]-y).*(Bm0[.,13]-y);
quan=quantile(Gphat,0.05);
index=Gphat.<=quan;
Gphat=index*10^5+Gphat;

/****************************Two Lag Included Estimation of A part *******************************************/

kc=1;
do until kc>nc;
ha2=hs2*h[kc,1];
m0=zeros(T,13);
i=1;
do until i>T;
u0i=data[i,lag_1]*ones(T,1) - data[.,lag_1];
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u0i~u1i;
xx02 = ones(T,1)~u0i~u2i ;
xx03 = ones(T,1)~u0i~u3i;
xx04 = ones(T,1)~u0i~u4i;
xx05 = ones(T,1)~u0i~u5i;
xx06 = ones(T,1)~u0i~u6i;
xx07 = ones(T,1)~u0i~u7i;
xx08 = ones(T,1)~u0i~u8i;
xx09 = ones(T,1)~u0i~u9i;
xx10 = ones(T,1)~u0i~u10i;
xx11 = ones(T,1)~u0i~u11i;
xx12 = ones(T,1)~u0i~u12i;
xx13 = ones(T,1)~u0i~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
w1 = fi(u0i/ha2).*fi(u1i/ha2);
w2 = fi(u0i/ha2).*fi(u2i/ha2);
w3 = fi(u0i/ha2).*fi(u3i/ha2);
w4 = fi(u0i/ha2).*fi(u4i/ha2);
w5 = fi(u0i/ha2).*fi(u5i/ha2);
w6 = fi(u0i/ha2).*fi(u6i/ha2);
w7 = fi(u0i/ha2).*fi(u7i/ha2);
w8 = fi(u0i/ha2).*fi(u8i/ha2);
w9 = fi(u0i/ha2).*fi(u9i/ha2);
w10 = fi(u0i/ha2).*fi(u10i/ha2);
w11 = fi(u0i/ha2).*fi(u11i/ha2);
w12 = fi(u0i/ha2).*fi(u12i/ha2);
w13 = fi(u0i/ha2).*fi(u13i/ha2);
wmat1 =diagrv((eye(T),w1)) ;
wmat2 =diagrv((eye(T),w2)) ;
wmat3 =diagrv((eye(T),w3)) ;
wmat4 =diagrv((eye(T),w4)) ;
wmat5=diagrv((eye(T),w5)) ;
wmat6 =diagrv((eye(T),w6)) ;
wmat7 =diagrv((eye(T),w7)) ;
wmat8 =diagrv((eye(T),w8)) ;
wmat9 =diagrv((eye(T),w9)) ;
wmat10 =diagrv((eye(T),w10)) ;
wmat11=diagrv((eye(T),w11)) ;
wmat12 =diagrv((eye(T),w12)) ;
wmat13 =diagrv((eye(T),w13)) ;

if det(xx01'wmat1*xx01) > epsln ;
 a2= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 m0[i,1] = a2[1,.] ;
endif;


if det(xx02'wmat2*xx02) > epsln ;
 a2= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 m0[i,2] = a2[1,.] ;
 endif;

if det(xx03'wmat3*xx03) > epsln ;
 a2= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 m0[i,3] = a2[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a2= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 m0[i,4] = a2[1,.] ;
endif;


if det(xx05'wmat5*xx05) > epsln ;
 a2= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 m0[i,5] = a2[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a2= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 m0[i,6] = a2[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 m0[i,7] = a[1,.] ;
endif;

if det(xx08'wmat8*xx08) > epsln ;
 a= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 m0[i,8] = a[1,.] ;
endif;


if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 m0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 m0[i,10] = a[1,.] ;
endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 m0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 m0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 m0[i,13] = a[1,.] ;
endif;
i=i+1;
endo;

R1=(m0[.,1]-y).*(m0[.,1]-y);
R2=(m0[.,2]-y).*(m0[.,2]-y);
R3=(m0[.,3]-y).*(m0[.,3]-y);
R4=(m0[.,4]-y).*(m0[.,4]-y);
R5=(m0[.,5]-y).*(m0[.,5]-y);
R6=(m0[.,6]-y).*(m0[.,6]-y);
R7=(m0[.,7]-y).*(m0[.,7]-y);
R8=(m0[.,8]-y).*(m0[.,8]-y);
R9=(m0[.,9]-y).*(m0[.,9]-y);
R10=(m0[.,10]-y).*(m0[.,10]-y);
R11=(m0[.,11]-y).*(m0[.,11]-y);
R12=(m0[.,12]-y).*(m0[.,12]-y);
R13=(m0[.,13]-y).*(m0[.,13]-y);
GAhat1[k,kc] = 1/T*sumc(R1);
GAhat2[k,kc]= 1/T*sumc(R2);
GAhat3[k,kc] = 1/T*sumc(R3);
GAhat4[k,kc]= 1/T*sumc(R4);
GAhat5[k,kc] = 1/T*sumc(R5);
GAhat6[k,kc]= 1/T*sumc(R6);
GAhat7[k,kc] = 1/T*sumc(R7);
GAhat8[k,kc]= 1/T*sumc(R8);
GAhat9[k,kc] = 1/T*sumc(R9);
GAhat10[k,kc]= 1/T*sumc(R10);
GAhat11[k,kc] = 1/T*sumc(R11);
GAhat12[k,kc]= 1/T*sumc(R12);
GAhat13[k,kc]= 1/T*sumc(R13);
GBhat1[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR1./Gphat[.,1])*1/T;
GBhat2[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR2./Gphat[.,2])*1/T;
GBhat3[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR3./Gphat[.,3])*1/T;
GBhat4[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR4./Gphat[.,4])*1/T;
GBhat5[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR5./Gphat[.,5])*1/T;
GBhat6[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR6./Gphat[.,6])*1/T;
GBhat7[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR7./Gphat[.,7])*1/T;
GBhat8[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR8./Gphat[.,8])*1/T;
GBhat9[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR9./Gphat[.,9])*1/T;
GBhat10[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR10./Gphat[.,10])*1/T;
GBhat11[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR11./Gphat[.,11])*1/T;
GBhat12[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR12./Gphat[.,12])*1/T;
GBhat13[k,kc] =2/(ha2^2)*1/(sqrt(2*pi))^2*1/T*sumc(BR13./Gphat[.,13])*1/T;
GFPE1[k,kc]=GAhat1[k,kc]+GBhat1[k,kc];
GFPE2[k,kc]=GAhat2[k,kc]+GBhat2[k,kc];
GFPE3[k,kc]=GAhat3[k,kc]+GBhat3[k,kc];
GFPE4[k,kc]=GAhat4[k,kc]+GBhat4[k,kc];
GFPE5[k,kc]=GAhat5[k,kc]+GBhat5[k,kc];
GFPE6[k,kc]=GAhat6[k,kc]+GBhat6[k,kc];
GFPE7[k,kc]=GAhat7[k,kc]+GBhat7[k,kc];
GFPE8[k,kc]=GAhat8[k,kc]+GBhat8[k,kc];
GFPE9[k,kc]=GAhat9[k,kc]+GBhat9[k,kc];
GFPE10[k,kc]=GAhat10[k,kc]+GBhat10[k,kc];
GFPE11[k,kc]=GAhat11[k,kc]+GBhat11[k,kc];
GFPE12[k,kc]=GAhat12[k,kc]+GBhat12[k,kc];
GFPE13[k,kc]=GAhat13[k,kc]+GBhat13[k,kc];
kc=kc+1;
endo;
min1=minc(GFPE1[k,.]');
min2=minc(GFPE2[k,.]');
min3=minc(GFPE3[k,.]');
min4=minc(GFPE4[k,.]');
min5=minc(GFPE5[k,.]');
min6=minc(GFPE6[k,.]');
min7=minc(GFPE7[k,.]');
min8=minc(GFPE8[k,.]');
min9=minc(GFPE9[k,.]');
min10=minc(GFPE10[k,.]');
min11=minc(GFPE11[k,.]');
min12=minc(GFPE12[k,.]');
min13=minc(GFPE13[k,.]');
minGFPE=min1~min2~min3~min4~min5~min6~min7~min8~min9~min10~min11~min12~min13;
minGFPE[.,lag_1]=10^10;
AFPE[k,2]=minc(minGFPE');
lag[k,2]=minindc(minGFPE');
lag_2=lag[k,2];


/****************************Three Lags Included *******************************************/

/****************************Three Lags Included Estimation of B part*******************************************/
i=1;
Bm0=zeros(T,13);
Gphat=zeros(T,13);
do until i>T;
u01i=data[i,lag_1]*ones(T,1) - data[.,lag_1];
u02i=data[i,lag_2]*ones(T,1) - data[.,lag_2];
u0i=u01i~u02i;
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u0i~u1i;
xx02 = ones(T,1)~u0i~u2i ;
xx03 = ones(T,1)~u0i~u3i;
xx04 = ones(T,1)~u0i~u4i;
xx05 = ones(T,1)~u0i~u5i;
xx06 = ones(T,1)~u0i~u6i;
xx07 = ones(T,1)~u0i~u7i;
xx08 = ones(T,1)~u0i~u8i;
xx09 = ones(T,1)~u0i~u9i;
xx10 = ones(T,1)~u0i~u10i;
xx11 = ones(T,1)~u0i~u11i;
xx12 = ones(T,1)~u0i~u12i;
xx13 = ones(T,1)~u0i~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
w1 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u1i/hs3);
w2 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u2i/hs3);
w3 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u3i/hs3);
w4 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u4i/hs3);
w5 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u5i/hs3);
w6 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u6i/hs3);
w7 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u7i/hs3);
w8 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u8i/hs3);
w9 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u9i/hs3);
w10 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u10i/hs3);
w11 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u11i/hs3);
w12 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u12i/hs3);
w13 = fi(u01i/hs3).*fi(u02i/hs3).*fi(u13i/hs3);
w1[i]=0;
w2[i]=0;
w3[i]=0;
w4[i]=0;
w5[i]=0;
w6[i]=0;
w7[i]=0;
w8[i]=0;
w9[i]=0;
w10[i]=0;
w11[i]=0;
w12[i]=0;
w13[i]=0;
wmat1 =diagrv((eye(T),w1)) ;
wmat2 =diagrv((eye(T),w2)) ;
wmat3 =diagrv((eye(T),w3)) ;
wmat4 =diagrv((eye(T),w4)) ;
wmat5=diagrv((eye(T),w5)) ;
wmat6 =diagrv((eye(T),w6)) ;
wmat7 =diagrv((eye(T),w7)) ;
wmat8 =diagrv((eye(T),w8)) ;
wmat9 =diagrv((eye(T),w9)) ;
wmat10 =diagrv((eye(T),w10)) ;
wmat11=diagrv((eye(T),w11)) ;
wmat12 =diagrv((eye(T),w12)) ;
wmat13 =diagrv((eye(T),w13)) ;

if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 Bm0[i,1] = a[1] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 Bm0[i,2] = a[1,.] ;
 endif;

if det(xx03'wmat3*xx03) > epsln ;
 a3= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 Bm0[i,3] = a3[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a4= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 Bm0[i,4] = a4[1,.] ;
endif;  

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 Bm0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a6= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 Bm0[i,6] = a6[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 Bm0[i,7] = a[1,.] ;
endif;

if det(xx08'wmat8*xx08) > epsln ;
 a= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 Bm0[i,8] = a[1,.] ;
endif;

if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 Bm0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 Bm0[i,10] = a[1,.] ;
endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 Bm0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 Bm0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 Bm0[i,13] = a[1,.] ;
endif;
/*kernel estimator of the density function leave-one-out*/
 LVO= ones(T,1);
 LVO[i]=0;
Gphat[i,1]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u1i/hs3))/((T-1)*hs3^3);
Gphat[i,2]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u2i/hs3))/((T-1)*hs3^3);
Gphat[i,3]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u3i/hs3))/((T-1)*hs3^3);
Gphat[i,4]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u4i/hs3))/((T-1)*hs3^3);
Gphat[i,5]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u5i/hs3))/((T-1)*hs3^3);
Gphat[i,6]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u6i/hs3))/((T-1)*hs3^3);
Gphat[i,7]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u7i/hs3))/((T-1)*hs3^3);
Gphat[i,8]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u8i/hs3))/((T-1)*hs3^3);
Gphat[i,9]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u9i/hs3))/((T-1)*hs3^3);
Gphat[i,10]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u10i/hs3))/((T-1)*hs3^3);
Gphat[i,11]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u11i/hs3))/((T-1)*hs3^3);
Gphat[i,12]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u12i/hs3))/((T-1)*hs3^3);
Gphat[i,13]=sumc(LVO.*fi(u01i/hs3).*fi(u02i/hs3).*fi(u13i/hs3))/((T-1)*hs3^3);
i=i+1;
endo;
quan=quantile(Gphat,0.05);
index=Gphat.<=quan;
Gphat=index*10^5+Gphat;
BR1=(Bm0[.,1]-y).*(Bm0[.,1]-y);
BR2=(Bm0[.,2]-y).*(Bm0[.,2]-y);
BR3=(Bm0[.,3]-y).*(Bm0[.,3]-y);
BR4=(Bm0[.,4]-y).*(Bm0[.,4]-y);
BR5=(Bm0[.,5]-y).*(Bm0[.,5]-y);
BR6=(Bm0[.,6]-y).*(Bm0[.,6]-y);
BR7=(Bm0[.,7]-y).*(Bm0[.,7]-y);
BR8=(Bm0[.,8]-y).*(Bm0[.,8]-y);
BR9=(Bm0[.,9]-y).*(Bm0[.,9]-y);
BR10=(Bm0[.,10]-y).*(Bm0[.,10]-y);
BR11=(Bm0[.,11]-y).*(Bm0[.,11]-y);
BR12=(Bm0[.,12]-y).*(Bm0[.,12]-y);
BR13=(Bm0[.,13]-y).*(Bm0[.,13]-y);

/****************************Three Lags Included Estimation of A part*******************************************/

kc=1;
do until kc>nc;
ha3=hs3*h[kc,1];
m0=zeros(T,13);
i=1;
do until i>T;
u01i=data[i,lag_1]*ones(T,1) - data[.,lag_1];
u02i=data[i,lag_2]*ones(T,1) - data[.,lag_2];
u0i=u01i~u02i;
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u0i~u1i;
xx02 = ones(T,1)~u0i~u2i ;
xx03 = ones(T,1)~u0i~u3i;
xx04 = ones(T,1)~u0i~u4i;
xx05 = ones(T,1)~u0i~u5i;
xx06 = ones(T,1)~u0i~u6i;
xx07 = ones(T,1)~u0i~u7i;
xx08 = ones(T,1)~u0i~u8i;
xx09 = ones(T,1)~u0i~u9i;
xx10 = ones(T,1)~u0i~u10i;
xx11 = ones(T,1)~u0i~u11i;
xx12 = ones(T,1)~u0i~u12i;
xx13 = ones(T,1)~u0i~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
w1 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u1i/ha3);
w2 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u2i/ha3);
w3 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u3i/ha3);
w4 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u4i/ha3);
w5 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u5i/ha3);
w6 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u6i/ha3);
w7 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u7i/ha3);
w8 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u8i/ha3);
w9 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u9i/ha3);
w10 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u10i/ha3);
w11 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u11i/ha3);
w12 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u12i/ha3);
w13 = fi(u01i/ha3).*fi(u02i/ha3).*fi(u13i/ha3);
wmat1 =diagrv((eye(T),w1)) ;
wmat2 =diagrv((eye(T),w2)) ;
wmat3 =diagrv((eye(T),w3)) ;
wmat4 =diagrv((eye(T),w4)) ;
wmat5=diagrv((eye(T),w5)) ;
wmat6 =diagrv((eye(T),w6)) ;
wmat7 =diagrv((eye(T),w7)) ;
wmat8 =diagrv((eye(T),w8)) ;
wmat9 =diagrv((eye(T),w9)) ;
wmat10 =diagrv((eye(T),w10)) ;
wmat11=diagrv((eye(T),w11)) ;
wmat12 =diagrv((eye(T),w12)) ;
wmat13 =diagrv((eye(T),w13)) ;

if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 m0[i,1] = a[1,.] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 m0[i,2] = a[1,.] ;
endif;

if det(xx03'wmat3*xx03) > epsln ;
 a= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 m0[i,3] = a[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 m0[i,4] = a[1,.] ;
endif;

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 m0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 m0[i,6] = a[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 m0[i,7] = a[1,.] ;
endif;


if det(xx08'wmat8*xx08) > epsln ;
 a2= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 m0[i,8] = a2[1,.] ;
endif;

if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 m0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 m0[i,10] = a[1,.] ;
 endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 m0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 m0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 m0[i,13] = a[1,.] ;
endif;
i=i+1;
endo;
R1=(m0[.,1]-y).*(m0[.,1]-y);
R2=(m0[.,2]-y).*(m0[.,2]-y);
R3=(m0[.,3]-y).*(m0[.,3]-y);
R4=(m0[.,4]-y).*(m0[.,4]-y);
R5=(m0[.,5]-y).*(m0[.,5]-y);
R6=(m0[.,6]-y).*(m0[.,6]-y);
R7=(m0[.,7]-y).*(m0[.,7]-y);
R8=(m0[.,8]-y).*(m0[.,8]-y);
R9=(m0[.,9]-y).*(m0[.,9]-y);
R10=(m0[.,10]-y).*(m0[.,10]-y);
R11=(m0[.,11]-y).*(m0[.,11]-y);
R12=(m0[.,12]-y).*(m0[.,12]-y);
R13=(m0[.,13]-y).*(m0[.,13]-y);
GAhat1[k,kc] = 1/T*sumc(R1);
GAhat2[k,kc]= 1/T*sumc(R2);
GAhat3[k,kc] = 1/T*sumc(R3);
GAhat4[k,kc]= 1/T*sumc(R4);
GAhat5[k,kc] = 1/T*sumc(R5);
GAhat6[k,kc]= 1/T*sumc(R6);
GAhat7[k,kc] = 1/T*sumc(R7);
GAhat8[k,kc]= 1/T*sumc(R8);
GAhat9[k,kc] = 1/T*sumc(R9);
GAhat10[k,kc]= 1/T*sumc(R10);
GAhat11[k,kc] = 1/T*sumc(R11);
GAhat12[k,kc]= 1/T*sumc(R12);
GAhat13[k,kc]= 1/T*sumc(R13);
GBhat1[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR1./Gphat[.,1])*1/T;
GBhat2[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR2./Gphat[.,2])*1/T;
GBhat3[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR3./Gphat[.,3])*1/T;
GBhat4[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR4./Gphat[.,4])*1/T;
GBhat5[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR5./Gphat[.,5])*1/T;
GBhat6[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR6./Gphat[.,6])*1/T;
GBhat7[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR7./Gphat[.,7])*1/T;
GBhat8[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR8./Gphat[.,8])*1/T;
GBhat9[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR9./Gphat[.,9])*1/T;
GBhat10[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR10./Gphat[.,10])*1/T;
GBhat11[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR11./Gphat[.,11])*1/T;
GBhat12[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR12./Gphat[.,12])*1/T;
GBhat13[k,kc] =2/(ha3^3)*1/(sqrt(2*pi))^3*1/T*sumc(BR13./Gphat[.,13])*1/T;
GFPE1[k,kc]=GAhat1[k,kc]+GBhat1[k,kc];
GFPE2[k,kc]=GAhat2[k,kc]+GBhat2[k,kc];
GFPE3[k,kc]=GAhat3[k,kc]+GBhat3[k,kc];
GFPE4[k,kc]=GAhat4[k,kc]+GBhat4[k,kc];
GFPE5[k,kc]=GAhat5[k,kc]+GBhat5[k,kc];
GFPE6[k,kc]=GAhat6[k,kc]+GBhat6[k,kc];
GFPE7[k,kc]=GAhat7[k,kc]+GBhat7[k,kc];
GFPE8[k,kc]=GAhat8[k,kc]+GBhat8[k,kc];
GFPE9[k,kc]=GAhat9[k,kc]+GBhat9[k,kc];
GFPE10[k,kc]=GAhat10[k,kc]+GBhat10[k,kc];
GFPE11[k,kc]=GAhat11[k,kc]+GBhat11[k,kc];
GFPE12[k,kc]=GAhat12[k,kc]+GBhat12[k,kc];
GFPE13[k,kc]=GAhat13[k,kc]+GBhat13[k,kc];
kc=kc+1;
endo;
min1=minc(GFPE1[k,.]');
min2=minc(GFPE2[k,.]');
min3=minc(GFPE3[k,.]');
min4=minc(GFPE4[k,.]');
min5=minc(GFPE5[k,.]');
min6=minc(GFPE6[k,.]');
min7=minc(GFPE7[k,.]');
min8=minc(GFPE8[k,.]');
min9=minc(GFPE9[k,.]');
min10=minc(GFPE10[k,.]');
min11=minc(GFPE11[k,.]');
min12=minc(GFPE12[k,.]');
min13=minc(GFPE13[k,.]');
minGFPE=min1~min2~min3~min4~min5~min6~min7~min8~min9~min10~min11~min12~min13;
minGFPE[.,lag_1]=10^10;
minGFPE[.,lag_2]=10^10;
AFPE[k,3]=minc(minGFPE');
lag[k,3]=minindc(minGFPE');
lag_3=lag[k,3];

/****************************Four Lags Included *******************************************/

/****************************Four Lags Included Estimation of B part*******************************************/
i=1;
Bm0=zeros(T,13);
Gphat=zeros(T,13);
do until i>T;
u01i=data[i,lag_1]*ones(T,1) - data[.,lag_1];
u02i=data[i,lag_2]*ones(T,1) - data[.,lag_2];
u03i=data[i,lag_3]*ones(T,1) - data[.,lag_3];
u0i=u01i~u02i~u03i;
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u0i~u1i;
xx02 = ones(T,1)~u0i~u2i ;
xx03 = ones(T,1)~u0i~u3i;
xx04 = ones(T,1)~u0i~u4i;
xx05 = ones(T,1)~u0i~u5i;
xx06 = ones(T,1)~u0i~u6i;
xx07 = ones(T,1)~u0i~u7i;
xx08 = ones(T,1)~u0i~u8i;
xx09 = ones(T,1)~u0i~u9i;
xx10 = ones(T,1)~u0i~u10i;
xx11 = ones(T,1)~u0i~u11i;
xx12 = ones(T,1)~u0i~u12i;
xx13 = ones(T,1)~u0i~u13i;;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
w1 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u1i/hs4);
w2 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u2i/hs4);
w3 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u3i/hs4);
w4 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u4i/hs4);
w5 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u5i/hs4);
w6 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u6i/hs4);
w7 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u7i/hs4);
w8 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u8i/hs4);
w9 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u9i/hs4);
w10 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u10i/hs4);
w11 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u11i/hs4);
w12 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u12i/hs4);
w13 = fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u13i/hs4);
w1[i]=0;
w2[i]=0;
w3[i]=0;
w4[i]=0;
w5[i]=0;
w6[i]=0;
w7[i]=0;
w8[i]=0;
w9[i]=0;
w10[i]=0;
w11[i]=0;
w12[i]=0;
w13[i]=0;
wmat1 =diagrv((eye(T),w1)) ;
wmat2 =diagrv((eye(T),w2)) ;
wmat3 =diagrv((eye(T),w3)) ;
wmat4 =diagrv((eye(T),w4)) ;
wmat5=diagrv((eye(T),w5)) ;
wmat6 =diagrv((eye(T),w6)) ;
wmat7 =diagrv((eye(T),w7)) ;
wmat8 =diagrv((eye(T),w8)) ;
wmat9 =diagrv((eye(T),w9)) ;
wmat10 =diagrv((eye(T),w10)) ;
wmat11=diagrv((eye(T),w11)) ;
wmat12 =diagrv((eye(T),w12)) ;
wmat13 =diagrv((eye(T),w13)) ;

if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 Bm0[i,1] = a[1] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 Bm0[i,2] = a[1,.] ;
 endif;

if det(xx03'wmat3*xx03) > epsln ;
 a3= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 Bm0[i,3] = a3[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a4= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 Bm0[i,4] = a4[1,.] ;
endif;  

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 Bm0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a6= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 Bm0[i,6] = a6[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 Bm0[i,7] = a[1,.] ;
endif;

if det(xx08'wmat8*xx08) > epsln ;
 a= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 Bm0[i,8] = a[1,.] ;
endif;

if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 Bm0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 Bm0[i,10] = a[1,.] ;
endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 Bm0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 Bm0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 Bm0[i,13] = a[1,.] ;
endif;
/*kernel estimator of the density function leanve-one-out */
 LVO= ones(T,1);
 LVO[i]=0;
Gphat[i,1]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u1i/hs4))/((T-1)*hs4^4);
Gphat[i,2]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u2i/hs4))/((T-1)*hs4^4);
Gphat[i,3]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u3i/hs4))/((T-1)*hs4^4);
Gphat[i,4]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u4i/hs4))/((T-1)*hs4^4);
Gphat[i,5]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u5i/hs4))/((T-1)*hs4^4);
Gphat[i,6]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u6i/hs4))/((T-1)*hs4^4);
Gphat[i,7]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u7i/hs4))/((T-1)*hs4^4);
Gphat[i,8]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u8i/hs4))/((T-1)*hs4^4);
Gphat[i,9]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u9i/hs4))/((T-1)*hs4^4);
Gphat[i,10]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u10i/hs4))/((T-1)*hs4^4);
Gphat[i,11]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u11i/hs4))/((T-1)*hs4^4);
Gphat[i,12]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u12i/hs4))/((T-1)*hs4^4);
Gphat[i,13]=sumc(LVO.*fi(u01i/hs4).*fi(u02i/hs4).*fi(u03i/hs4).*fi(u13i/hs4))/((T-1)*hs4^4);
i=i+1;
endo;
quan=quantile(Gphat,0.05);
index=Gphat.<=quan;
Gphat=index*10^5+Gphat;
BR1=(Bm0[.,1]-y).*(Bm0[.,1]-y);
BR2=(Bm0[.,2]-y).*(Bm0[.,2]-y);
BR3=(Bm0[.,3]-y).*(Bm0[.,3]-y);
BR4=(Bm0[.,4]-y).*(Bm0[.,4]-y);
BR5=(Bm0[.,5]-y).*(Bm0[.,5]-y);
BR6=(Bm0[.,6]-y).*(Bm0[.,6]-y);
BR7=(Bm0[.,7]-y).*(Bm0[.,7]-y);
BR8=(Bm0[.,8]-y).*(Bm0[.,8]-y);
BR9=(Bm0[.,9]-y).*(Bm0[.,9]-y);
BR10=(Bm0[.,10]-y).*(Bm0[.,10]-y);
BR11=(Bm0[.,11]-y).*(Bm0[.,11]-y);
BR12=(Bm0[.,12]-y).*(Bm0[.,12]-y);
BR13=(Bm0[.,13]-y).*(Bm0[.,13]-y);

/****************************Four Lags Included Estimation of A part*******************************************/

kc=1;
do until kc>nc;
ha4=hs4*h[kc,1];
m0=zeros(T,13);
i=1;
do until i>T;
u01i=data[i,lag_1]*ones(T,1) - data[.,lag_1];
u02i=data[i,lag_2]*ones(T,1) - data[.,lag_2];
u03i=data[i,lag_3]*ones(T,1) - data[.,lag_3];
u0i=u01i~u02i~u03i;
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u0i~u1i;
xx02 = ones(T,1)~u0i~u2i ;
xx03 = ones(T,1)~u0i~u3i;
xx04 = ones(T,1)~u0i~u4i;
xx05 = ones(T,1)~u0i~u5i;
xx06 = ones(T,1)~u0i~u6i;
xx07 = ones(T,1)~u0i~u7i;
xx08 = ones(T,1)~u0i~u8i;
xx09 = ones(T,1)~u0i~u9i;
xx10 = ones(T,1)~u0i~u10i;
xx11 = ones(T,1)~u0i~u11i;
xx12 = ones(T,1)~u0i~u12i;
xx13 = ones(T,1)~u0i~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
w1 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u1i/ha4);
w2 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u2i/ha4);
w3 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u3i/ha4);
w4 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u4i/ha4);
w5 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u5i/ha4);
w6 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u6i/ha4);
w7 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u7i/ha4);
w8 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u8i/ha4);
w9 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u9i/ha4);
w10 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u10i/ha4);
w11 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u11i/ha4);
w12 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u12i/ha4);
w13 = fi(u01i/ha4).*fi(u02i/ha4).*fi(u03i/ha4).*fi(u13i/ha4);
wmat1 =diagrv((eye(T),w1)) ;
wmat2 =diagrv((eye(T),w2)) ;
wmat3 =diagrv((eye(T),w3)) ;
wmat4 =diagrv((eye(T),w4)) ;
wmat5=diagrv((eye(T),w5)) ;
wmat6 =diagrv((eye(T),w6)) ;
wmat7 =diagrv((eye(T),w7)) ;
wmat8 =diagrv((eye(T),w8)) ;
wmat9 =diagrv((eye(T),w9)) ;
wmat10 =diagrv((eye(T),w10)) ;
wmat11=diagrv((eye(T),w11)) ;
wmat12 =diagrv((eye(T),w12)) ;
wmat13 =diagrv((eye(T),w13)) ;

if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 m0[i,1] = a[1,.] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 m0[i,2] = a[1,.] ;
endif;

if det(xx03'wmat3*xx03) > epsln ;
 a= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 m0[i,3] = a[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 m0[i,4] = a[1,.] ;
endif;

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 m0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 m0[i,6] = a[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 m0[i,7] = a[1,.] ;
endif;


if det(xx08'wmat8*xx08) > epsln ;
 a2= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 m0[i,8] = a2[1,.] ;
endif;

if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 m0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 m0[i,10] = a[1,.] ;
 endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 m0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 m0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 m0[i,13] = a[1,.] ;
endif;
i=i+1;
endo;
R1=(m0[.,1]-y).*(m0[.,1]-y);
R2=(m0[.,2]-y).*(m0[.,2]-y);
R3=(m0[.,3]-y).*(m0[.,3]-y);
R4=(m0[.,4]-y).*(m0[.,4]-y);
R5=(m0[.,5]-y).*(m0[.,5]-y);
R6=(m0[.,6]-y).*(m0[.,6]-y);
R7=(m0[.,7]-y).*(m0[.,7]-y);
R8=(m0[.,8]-y).*(m0[.,8]-y);
R9=(m0[.,9]-y).*(m0[.,9]-y);
R10=(m0[.,10]-y).*(m0[.,10]-y);
R11=(m0[.,11]-y).*(m0[.,11]-y);
R12=(m0[.,12]-y).*(m0[.,12]-y);
R13=(m0[.,13]-y).*(m0[.,13]-y);
GAhat1[k,kc] = 1/T*sumc(R1);
GAhat2[k,kc]= 1/T*sumc(R2);
GAhat3[k,kc] = 1/T*sumc(R3);
GAhat4[k,kc]= 1/T*sumc(R4);
GAhat5[k,kc] = 1/T*sumc(R5);
GAhat6[k,kc]= 1/T*sumc(R6);
GAhat7[k,kc] = 1/T*sumc(R7);
GAhat8[k,kc]= 1/T*sumc(R8);
GAhat9[k,kc] = 1/T*sumc(R9);
GAhat10[k,kc]= 1/T*sumc(R10);
GAhat11[k,kc] = 1/T*sumc(R11);
GAhat12[k,kc]= 1/T*sumc(R12);
GAhat13[k,kc]= 1/T*sumc(R13);
GBhat1[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR1./Gphat[.,1])*1/T;
GBhat2[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR2./Gphat[.,2])*1/T;
GBhat3[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR3./Gphat[.,3])*1/T;
GBhat4[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR4./Gphat[.,4])*1/T;
GBhat5[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR5./Gphat[.,5])*1/T;
GBhat6[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR6./Gphat[.,6])*1/T;
GBhat7[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR7./Gphat[.,7])*1/T;
GBhat8[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR8./Gphat[.,8])*1/T;
GBhat9[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR9./Gphat[.,9])*1/T;
GBhat10[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR10./Gphat[.,10])*1/T;
GBhat11[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR11./Gphat[.,11])*1/T;
GBhat12[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR12./Gphat[.,12])*1/T;
GBhat13[k,kc] =2/(ha4^4)*1/(sqrt(2*pi))^4*1/T*sumc(BR13./Gphat[.,13])*1/T;
GFPE1[k,kc]=GAhat1[k,kc]+GBhat1[k,kc];
GFPE2[k,kc]=GAhat2[k,kc]+GBhat2[k,kc];
GFPE3[k,kc]=GAhat3[k,kc]+GBhat3[k,kc];
GFPE4[k,kc]=GAhat4[k,kc]+GBhat4[k,kc];
GFPE5[k,kc]=GAhat5[k,kc]+GBhat5[k,kc];
GFPE6[k,kc]=GAhat6[k,kc]+GBhat6[k,kc];
GFPE7[k,kc]=GAhat7[k,kc]+GBhat7[k,kc];
GFPE8[k,kc]=GAhat8[k,kc]+GBhat8[k,kc];
GFPE9[k,kc]=GAhat9[k,kc]+GBhat9[k,kc];
GFPE10[k,kc]=GAhat10[k,kc]+GBhat10[k,kc];
GFPE11[k,kc]=GAhat11[k,kc]+GBhat11[k,kc];
GFPE12[k,kc]=GAhat12[k,kc]+GBhat12[k,kc];
GFPE13[k,kc]=GAhat13[k,kc]+GBhat13[k,kc];
kc=kc+1;
endo;
min1=minc(GFPE1[k,.]');
min2=minc(GFPE2[k,.]');
min3=minc(GFPE3[k,.]');
min4=minc(GFPE4[k,.]');
min5=minc(GFPE5[k,.]');
min6=minc(GFPE6[k,.]');
min7=minc(GFPE7[k,.]');
min8=minc(GFPE8[k,.]');
min9=minc(GFPE9[k,.]');
min10=minc(GFPE10[k,.]');
min11=minc(GFPE11[k,.]');
min12=minc(GFPE12[k,.]');
min13=minc(GFPE13[k,.]');
minGFPE=min1~min2~min3~min4~min5~min6~min7~min8~min9~min10~min11~min12~min13;
minGFPE[.,lag_1]=10^10;
minGFPE[.,lag_2]=10^10;
minGFPE[.,lag_3]=10^10;
AFPE[k,4]=minc(minGFPE');
lag[k,4]=minindc(minGFPE');
lag_4=lag[k,4];

/****************************Five Lags Included *******************************************/

/****************************Five Lags Included Estimation of B part*******************************************/
i=1;
Bm0=zeros(T,13);
Gphat=zeros(T,13);
do until i>T;
u01i=data[i,lag_1]*ones(T,1) - data[.,lag_1];
u02i=data[i,lag_2]*ones(T,1) - data[.,lag_2];
u03i=data[i,lag_3]*ones(T,1) - data[.,lag_3];
u04i=data[i,lag_4]*ones(T,1) - data[.,lag_4];
u0i=u01i~u02i~u03i~u04i;
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u0i~u1i;
xx02 = ones(T,1)~u0i~u2i ;
xx03 = ones(T,1)~u0i~u3i;
xx04 = ones(T,1)~u0i~u4i;
xx05 = ones(T,1)~u0i~u5i;
xx06 = ones(T,1)~u0i~u6i;
xx07 = ones(T,1)~u0i~u7i;
xx08 = ones(T,1)~u0i~u8i;
xx09 = ones(T,1)~u0i~u9i;
xx10 = ones(T,1)~u0i~u10i;
xx11 = ones(T,1)~u0i~u11i;
xx12 = ones(T,1)~u0i~u12i;
xx13 = ones(T,1)~u0i~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
w1 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u1i/hs5);
w2 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u2i/hs5);
w3 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u3i/hs5);
w4 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u4i/hs5);
w5 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u5i/hs5);
w6 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u6i/hs5);
w7 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u7i/hs5);
w8 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u8i/hs5);
w9 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u9i/hs5);
w10 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u10i/hs5);
w11 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u11i/hs5);
w12 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u12i/hs5);
w13 = fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u13i/hs5);
w1[i]=0;
w2[i]=0;
w3[i]=0;
w4[i]=0;
w5[i]=0;
w6[i]=0;
w7[i]=0;
w8[i]=0;
w9[i]=0;
w10[i]=0;
w11[i]=0;
w12[i]=0;
w13[i]=0;
wmat1 =diagrv((eye(T),w1)) ;
wmat2 =diagrv((eye(T),w2)) ;
wmat3 =diagrv((eye(T),w3)) ;
wmat4 =diagrv((eye(T),w4)) ;
wmat5=diagrv((eye(T),w5)) ;
wmat6 =diagrv((eye(T),w6)) ;
wmat7 =diagrv((eye(T),w7)) ;
wmat8 =diagrv((eye(T),w8)) ;
wmat9 =diagrv((eye(T),w9)) ;
wmat10 =diagrv((eye(T),w10)) ;
wmat11=diagrv((eye(T),w11)) ;
wmat12 =diagrv((eye(T),w12)) ;
wmat13 =diagrv((eye(T),w13)) ;

if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 Bm0[i,1] = a[1] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 Bm0[i,2] = a[1,.] ;
 endif;

if det(xx03'wmat3*xx03) > epsln ;
 a3= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 Bm0[i,3] = a3[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a4= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 Bm0[i,4] = a4[1,.] ;
endif;  

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 Bm0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a6= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 Bm0[i,6] = a6[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 Bm0[i,7] = a[1,.] ;
endif;

if det(xx08'wmat8*xx08) > epsln ;
 a= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 Bm0[i,8] = a[1,.] ;
endif;

if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 Bm0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 Bm0[i,10] = a[1,.] ;
endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 Bm0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 Bm0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 Bm0[i,13] = a[1,.] ;
endif;
/*kernel estimator of the density function leave-one-out */
 LVO= ones(T,1);
 LVO[i]=0;
Gphat[i,1]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u1i/hs5))/((T-1)*hs5^5);
Gphat[i,2]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u2i/hs5))/((T-1)*hs5^5);
Gphat[i,3]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u3i/hs5))/((T-1)*hs5^5);
Gphat[i,4]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u4i/hs5))/((T-1)*hs5^5);
Gphat[i,5]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u5i/hs5))/((T-1)*hs5^5);
Gphat[i,6]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u6i/hs5))/((T-1)*hs5^5);
Gphat[i,7]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u7i/hs5))/((T-1)*hs5^5);
Gphat[i,8]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u8i/hs5))/((T-1)*hs5^5);
Gphat[i,9]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u9i/hs5))/((T-1)*hs5^5);
Gphat[i,10]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u10i/hs5))/((T-1)*hs5^5);
Gphat[i,11]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u11i/hs5))/((T-1)*hs5^5);
Gphat[i,12]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u12i/hs5))/((T-1)*hs5^5);
Gphat[i,13]=sumc(LVO.*fi(u01i/hs5).*fi(u02i/hs5).*fi(u03i/hs5).*fi(u04i/hs5).*fi(u13i/hs5))/((T-1)*hs5^5);
i=i+1;
endo;
quan=quantile(Gphat,0.05);
index=Gphat.<=quan;
Gphat=index*10^5+Gphat;
BR1=(Bm0[.,1]-y).*(Bm0[.,1]-y);
BR2=(Bm0[.,2]-y).*(Bm0[.,2]-y);
BR3=(Bm0[.,3]-y).*(Bm0[.,3]-y);
BR4=(Bm0[.,4]-y).*(Bm0[.,4]-y);
BR5=(Bm0[.,5]-y).*(Bm0[.,5]-y);
BR6=(Bm0[.,6]-y).*(Bm0[.,6]-y);
BR7=(Bm0[.,7]-y).*(Bm0[.,7]-y);
BR8=(Bm0[.,8]-y).*(Bm0[.,8]-y);
BR9=(Bm0[.,9]-y).*(Bm0[.,9]-y);
BR10=(Bm0[.,10]-y).*(Bm0[.,10]-y);
BR11=(Bm0[.,11]-y).*(Bm0[.,11]-y);
BR12=(Bm0[.,12]-y).*(Bm0[.,12]-y);
BR13=(Bm0[.,13]-y).*(Bm0[.,13]-y);

/****************************Five Lags Included Estimation of A part*******************************************/

kc=1;
do until kc>nc;
ha5=hs5*h[kc,1];
m0=zeros(T,13);
i=1;
do until i>T;
u01i=data[i,lag_1]*ones(T,1) - data[.,lag_1];
u02i=data[i,lag_2]*ones(T,1) - data[.,lag_2];
u03i=data[i,lag_3]*ones(T,1) - data[.,lag_3];
u04i=data[i,lag_4]*ones(T,1) - data[.,lag_4];
u0i=u01i~u02i~u03i~u04i;
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u0i~u1i;
xx02 = ones(T,1)~u0i~u2i ;
xx03 = ones(T,1)~u0i~u3i;
xx04 = ones(T,1)~u0i~u4i;
xx05 = ones(T,1)~u0i~u5i;
xx06 = ones(T,1)~u0i~u6i;
xx07 = ones(T,1)~u0i~u7i;
xx08 = ones(T,1)~u0i~u8i;
xx09 = ones(T,1)~u0i~u9i;
xx10 = ones(T,1)~u0i~u10i;
xx11 = ones(T,1)~u0i~u11i;
xx12 = ones(T,1)~u0i~u12i;
xx13 = ones(T,1)~u0i~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
w1 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u1i/ha5);
w2 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u2i/ha5);
w3 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u3i/ha5);
w4 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u4i/ha5);
w5 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u5i/ha5);
w6 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u6i/ha5);
w7 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u7i/ha5);
w8 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u8i/ha5);
w9 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u9i/ha5);
w10 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u10i/ha5);
w11 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u11i/ha5);
w12 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u12i/ha5);
w13 = fi(u01i/ha5).*fi(u02i/ha5).*fi(u03i/ha5).*fi(u04i/ha5).*fi(u13i/ha5);
wmat1 =diagrv((eye(T),w1)) ;
wmat2 =diagrv((eye(T),w2)) ;
wmat3 =diagrv((eye(T),w3)) ;
wmat4 =diagrv((eye(T),w4)) ;
wmat5=diagrv((eye(T),w5)) ;
wmat6 =diagrv((eye(T),w6)) ;
wmat7 =diagrv((eye(T),w7)) ;
wmat8 =diagrv((eye(T),w8)) ;
wmat9 =diagrv((eye(T),w9)) ;
wmat10 =diagrv((eye(T),w10)) ;
wmat11=diagrv((eye(T),w11)) ;
wmat12 =diagrv((eye(T),w12)) ;
wmat13 =diagrv((eye(T),w13)) ;

if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 m0[i,1] = a[1,.] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 m0[i,2] = a[1,.] ;
endif;

if det(xx03'wmat3*xx03) > epsln ;
 a= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 m0[i,3] = a[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 m0[i,4] = a[1,.] ;
endif;

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 m0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 m0[i,6] = a[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 m0[i,7] = a[1,.] ;
endif;


if det(xx08'wmat8*xx08) > epsln ;
 a2= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 m0[i,8] = a2[1,.] ;
endif;

if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 m0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 m0[i,10] = a[1,.] ;
 endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 m0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 m0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 m0[i,13] = a[1,.] ;
endif;
i=i+1;
endo;
R1=(m0[.,1]-y).*(m0[.,1]-y);
R2=(m0[.,2]-y).*(m0[.,2]-y);
R3=(m0[.,3]-y).*(m0[.,3]-y);
R4=(m0[.,4]-y).*(m0[.,4]-y);
R5=(m0[.,5]-y).*(m0[.,5]-y);
R6=(m0[.,6]-y).*(m0[.,6]-y);
R7=(m0[.,7]-y).*(m0[.,7]-y);
R8=(m0[.,8]-y).*(m0[.,8]-y);
R9=(m0[.,9]-y).*(m0[.,9]-y);
R10=(m0[.,10]-y).*(m0[.,10]-y);
R11=(m0[.,11]-y).*(m0[.,11]-y);
R12=(m0[.,12]-y).*(m0[.,12]-y);
R13=(m0[.,13]-y).*(m0[.,13]-y);
GAhat1[k,kc] = 1/T*sumc(R1);
GAhat2[k,kc]= 1/T*sumc(R2);
GAhat3[k,kc] = 1/T*sumc(R3);
GAhat4[k,kc]= 1/T*sumc(R4);
GAhat5[k,kc] = 1/T*sumc(R5);
GAhat6[k,kc]= 1/T*sumc(R6);
GAhat7[k,kc] = 1/T*sumc(R7);
GAhat8[k,kc]= 1/T*sumc(R8);
GAhat9[k,kc] = 1/T*sumc(R9);
GAhat10[k,kc]= 1/T*sumc(R10);
GAhat11[k,kc] = 1/T*sumc(R11);
GAhat12[k,kc]= 1/T*sumc(R12);
GAhat13[k,kc]= 1/T*sumc(R13);
GBhat1[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR1./Gphat[.,1])*1/T;
GBhat2[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR2./Gphat[.,2])*1/T;
GBhat3[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR3./Gphat[.,3])*1/T;
GBhat4[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR4./Gphat[.,4])*1/T;
GBhat5[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR5./Gphat[.,5])*1/T;
GBhat6[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR6./Gphat[.,6])*1/T;
GBhat7[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR7./Gphat[.,7])*1/T;
GBhat8[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR8./Gphat[.,8])*1/T;
GBhat9[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR9./Gphat[.,9])*1/T;
GBhat10[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR10./Gphat[.,10])*1/T;
GBhat11[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR11./Gphat[.,11])*1/T;
GBhat12[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR12./Gphat[.,12])*1/T;
GBhat13[k,kc] =2/(ha5^5)*1/(sqrt(2*pi))^5*1/T*sumc(BR13./Gphat[.,13])*1/T;
GFPE1[k,kc]=GAhat1[k,kc]+GBhat1[k,kc];
GFPE2[k,kc]=GAhat2[k,kc]+GBhat2[k,kc];
GFPE3[k,kc]=GAhat3[k,kc]+GBhat3[k,kc];
GFPE4[k,kc]=GAhat4[k,kc]+GBhat4[k,kc];
GFPE5[k,kc]=GAhat5[k,kc]+GBhat5[k,kc];
GFPE6[k,kc]=GAhat6[k,kc]+GBhat6[k,kc];
GFPE7[k,kc]=GAhat7[k,kc]+GBhat7[k,kc];
GFPE8[k,kc]=GAhat8[k,kc]+GBhat8[k,kc];
GFPE9[k,kc]=GAhat9[k,kc]+GBhat9[k,kc];
GFPE10[k,kc]=GAhat10[k,kc]+GBhat10[k,kc];
GFPE11[k,kc]=GAhat11[k,kc]+GBhat11[k,kc];
GFPE12[k,kc]=GAhat12[k,kc]+GBhat12[k,kc];
GFPE13[k,kc]=GAhat13[k,kc]+GBhat13[k,kc];
kc=kc+1;
endo;
min1=minc(GFPE1[k,.]');
min2=minc(GFPE2[k,.]');
min3=minc(GFPE3[k,.]');
min4=minc(GFPE4[k,.]');
min5=minc(GFPE5[k,.]');
min6=minc(GFPE6[k,.]');
min7=minc(GFPE7[k,.]');
min8=minc(GFPE8[k,.]');
min9=minc(GFPE9[k,.]');
min10=minc(GFPE10[k,.]');
min11=minc(GFPE11[k,.]');
min12=minc(GFPE12[k,.]');
min13=minc(GFPE13[k,.]');
minGFPE=min1~min2~min3~min4~min5~min6~min7~min8~min9~min10~min11~min12~min13;
minGFPE[.,lag_1]=10^10;
minGFPE[.,lag_2]=10^10;
minGFPE[.,lag_3]=10^10;
minGFPE[.,lag_4]=10^10;
AFPE[k,5]=minc(minGFPE');
lag[k,5]=minindc(minGFPE');
lag_5=lag[k,5];

/****************************Six Lags Included *******************************************/

/****************************Six Lags Included Estimation of B part*******************************************/
i=1;
Bm0=zeros(T,13);
Gphat=zeros(T,13);
do until i>T;
u01i=data[i,lag_1]*ones(T,1) - data[.,lag_1];
u02i=data[i,lag_2]*ones(T,1) - data[.,lag_2];
u03i=data[i,lag_3]*ones(T,1) - data[.,lag_3];
u04i=data[i,lag_4]*ones(T,1) - data[.,lag_4];
u05i=data[i,lag_5]*ones(T,1) - data[.,lag_5];
u0i=u01i~u02i~u03i~u04i~u05i;
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u0i~u1i;
xx02 = ones(T,1)~u0i~u2i ;
xx03 = ones(T,1)~u0i~u3i;
xx04 = ones(T,1)~u0i~u4i;
xx05 = ones(T,1)~u0i~u5i;
xx06 = ones(T,1)~u0i~u6i;
xx07 = ones(T,1)~u0i~u7i;
xx08 = ones(T,1)~u0i~u8i;
xx09 = ones(T,1)~u0i~u9i;
xx10 = ones(T,1)~u0i~u10i;
xx11 = ones(T,1)~u0i~u11i;
xx12 = ones(T,1)~u0i~u12i;
xx13 = ones(T,1)~u0i~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
w1 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u1i/hs6);
w2 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u2i/hs6);
w3 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u3i/hs6);
w4 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u4i/hs6);
w5 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u5i/hs6);
w6 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u6i/hs6);
w7 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u7i/hs6);
w8 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u8i/hs6);
w9 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u9i/hs6);
w10 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u10i/hs6);
w11 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u11i/hs6);
w12 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u12i/hs6);
w13 = fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u13i/hs6);
w1[i]=0;
w2[i]=0;
w3[i]=0;
w4[i]=0;
w5[i]=0;
w6[i]=0;
w7[i]=0;
w8[i]=0;
w9[i]=0;
w10[i]=0;
w11[i]=0;
w12[i]=0;
w13[i]=0;
wmat1 =diagrv((eye(T),w1)) ;
wmat2 =diagrv((eye(T),w2)) ;
wmat3 =diagrv((eye(T),w3)) ;
wmat4 =diagrv((eye(T),w4)) ;
wmat5=diagrv((eye(T),w5)) ;
wmat6 =diagrv((eye(T),w6)) ;
wmat7 =diagrv((eye(T),w7)) ;
wmat8 =diagrv((eye(T),w8)) ;
wmat9 =diagrv((eye(T),w9)) ;
wmat10 =diagrv((eye(T),w10)) ;
wmat11=diagrv((eye(T),w11)) ;
wmat12 =diagrv((eye(T),w12)) ;
wmat13 =diagrv((eye(T),w13)) ;

if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 Bm0[i,1] = a[1] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 Bm0[i,2] = a[1,.] ;
 endif;

if det(xx03'wmat3*xx03) > epsln ;
 a3= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 Bm0[i,3] = a3[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a4= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 Bm0[i,4] = a4[1,.] ;
endif;  

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 Bm0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a6= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 Bm0[i,6] = a6[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 Bm0[i,7] = a[1,.] ;
endif;

if det(xx08'wmat8*xx08) > epsln ;
 a= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 Bm0[i,8] = a[1,.] ;
endif;

if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 Bm0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 Bm0[i,10] = a[1,.] ;
endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 Bm0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 Bm0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 Bm0[i,13] = a[1,.] ;
endif;
/*kernel estimator of the density function leave-one-out*/
 LVO= ones(T,1);
 LVO[i]=0;
Gphat[i,1]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u1i/hs6))/((T-1)*hs6^6);
Gphat[i,2]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u2i/hs6))/((T-1)*hs6^6);
Gphat[i,3]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u3i/hs6))/((T-1)*hs6^6);
Gphat[i,4]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u4i/hs6))/((T-1)*hs6^6);
Gphat[i,5]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u5i/hs6))/((T-1)*hs6^6);
Gphat[i,6]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u6i/hs6))/((T-1)*hs6^6);
Gphat[i,7]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u7i/hs6))/((T-1)*hs6^6);
Gphat[i,8]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u8i/hs6))/((T-1)*hs6^6);
Gphat[i,9]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u9i/hs6))/((T-1)*hs6^6);
Gphat[i,10]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u10i/hs6))/((T-1)*hs6^6);
Gphat[i,11]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u11i/hs6))/((T-1)*hs6^6);
Gphat[i,12]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u12i/hs6))/((T-1)*hs6^6);
Gphat[i,13]=sumc(LVO.*fi(u01i/hs6).*fi(u02i/hs6).*fi(u03i/hs6).*fi(u04i/hs6).*fi(u05i/hs6).*fi(u13i/hs6))/((T-1)*hs6^6);
i=i+1;
endo;
quan=quantile(Gphat,0.05);
index=Gphat.<=quan;
Gphat=index*10^5+Gphat;
BR1=(Bm0[.,1]-y).*(Bm0[.,1]-y);
BR2=(Bm0[.,2]-y).*(Bm0[.,2]-y);
BR3=(Bm0[.,3]-y).*(Bm0[.,3]-y);
BR4=(Bm0[.,4]-y).*(Bm0[.,4]-y);
BR5=(Bm0[.,5]-y).*(Bm0[.,5]-y);
BR6=(Bm0[.,6]-y).*(Bm0[.,6]-y);
BR7=(Bm0[.,7]-y).*(Bm0[.,7]-y);
BR8=(Bm0[.,8]-y).*(Bm0[.,8]-y);
BR9=(Bm0[.,9]-y).*(Bm0[.,9]-y);
BR10=(Bm0[.,10]-y).*(Bm0[.,10]-y);
BR11=(Bm0[.,11]-y).*(Bm0[.,11]-y);
BR12=(Bm0[.,12]-y).*(Bm0[.,12]-y);
BR13=(Bm0[.,13]-y).*(Bm0[.,13]-y);

/****************************Six Lags Included Estimation of A part*******************************************/

kc=1;
do until kc>nc;
ha6=hs6*h[kc,1];
m0=zeros(T,13);
i=1;
do until i>T;
u01i=data[i,lag_1]*ones(T,1) - data[.,lag_1];
u02i=data[i,lag_2]*ones(T,1) - data[.,lag_2];
u03i=data[i,lag_3]*ones(T,1) - data[.,lag_3];
u04i=data[i,lag_4]*ones(T,1) - data[.,lag_4];
u05i=data[i,lag_5]*ones(T,1) - data[.,lag_5];
u0i=u01i~u02i~u03i~u04i~u05i;
u1i= (data[i,1]*ones(T,1) - data[.,1]);
u2i= (data[i,2]*ones(T,1) - data[.,2]);
u3i= (data[i,3]*ones(T,1) - data[.,3]);
u4i= (data[i,4]*ones(T,1) - data[.,4]);
u5i= (data[i,5]*ones(T,1) - data[.,5]);
u6i= (data[i,6]*ones(T,1) - data[.,6]);
u7i= (data[i,7]*ones(T,1) - data[.,7]);
u8i= (data[i,8]*ones(T,1) - data[.,8]);
u9i= (data[i,9]*ones(T,1) - data[.,9]);
u10i= (data[i,10]*ones(T,1) - data[.,10]);
u11i= (data[i,11]*ones(T,1) - data[.,11]);
u12i= (data[i,12]*ones(T,1) - data[.,12]);
u13i= (data[i,13]*ones(T,1) - data[.,13]);
/*xx01 = ones(T,1)~u0i~u1i;
xx02 = ones(T,1)~u0i~u2i ;
xx03 = ones(T,1)~u0i~u3i;
xx04 = ones(T,1)~u0i~u4i;
xx05 = ones(T,1)~u0i~u5i;
xx06 = ones(T,1)~u0i~u6i;
xx07 = ones(T,1)~u0i~u7i;
xx08 = ones(T,1)~u0i~u8i;
xx09 = ones(T,1)~u0i~u9i;
xx10 = ones(T,1)~u0i~u10i;
xx11 = ones(T,1)~u0i~u11i;
xx12 = ones(T,1)~u0i~u12i;
xx13 = ones(T,1)~u0i~u13i;*/
xx01=ones(T,1);
xx02=ones(T,1);
xx03=ones(T,1);
xx04=ones(T,1);
xx05=ones(T,1);
xx06=ones(T,1);
xx07=ones(T,1);
xx08=ones(T,1);
xx09=ones(T,1);
xx10=ones(T,1);
xx11=ones(T,1);
xx12=ones(T,1);
xx13=ones(T,1);
w1 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u1i/ha6);
w2 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u2i/ha6);
w3 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u3i/ha6);
w4 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u4i/ha6);
w5 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u5i/ha6);
w6 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u6i/ha6);
w7 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u7i/ha6);
w8 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u8i/ha6);
w9 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u9i/ha6);
w10 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u10i/ha6);
w11 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u11i/ha6);
w12 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u12i/ha6);
w13 = fi(u01i/ha6).*fi(u02i/ha6).*fi(u03i/ha6).*fi(u04i/ha6).*fi(u05i/ha6).*fi(u13i/ha6);
wmat1 =diagrv((eye(T),w1)) ;
wmat2 =diagrv((eye(T),w2)) ;
wmat3 =diagrv((eye(T),w3)) ;
wmat4 =diagrv((eye(T),w4)) ;
wmat5=diagrv((eye(T),w5)) ;
wmat6 =diagrv((eye(T),w6)) ;
wmat7 =diagrv((eye(T),w7)) ;
wmat8 =diagrv((eye(T),w8)) ;
wmat9 =diagrv((eye(T),w9)) ;
wmat10 =diagrv((eye(T),w10)) ;
wmat11=diagrv((eye(T),w11)) ;
wmat12 =diagrv((eye(T),w12)) ;
wmat13 =diagrv((eye(T),w13)) ;

if det(xx01'wmat1*xx01) > epsln ;
 a= pinv(xx01'wmat1*xx01)*xx01'wmat1'y ;
 m0[i,1] = a[1,.] ;
endif;

if det(xx02'wmat2*xx02) > epsln ;
 a= pinv(xx02'wmat2*xx02)*xx02'wmat2'y ;
 m0[i,2] = a[1,.] ;
endif;

if det(xx03'wmat3*xx03) > epsln ;
 a= pinv(xx03'wmat3*xx03)*xx03'wmat3'y ;
 m0[i,3] = a[1,.] ;
endif;

if det(xx04'wmat4*xx04) > epsln ;
 a= pinv(xx04'wmat4*xx04)*xx04'wmat4'y ;
 m0[i,4] = a[1,.] ;
endif;

if det(xx05'wmat5*xx05) > epsln ;
 a= pinv(xx05'wmat5*xx05)*xx05'wmat5'y ;
 m0[i,5] = a[1,.] ;
endif;

if det(xx06'wmat6*xx06) > epsln ;
 a= pinv(xx06'wmat6*xx06)*xx06'wmat6'y ;
 m0[i,6] = a[1,.] ;
endif;

if det(xx07'wmat7*xx07) > epsln ;
 a= pinv(xx07'wmat7*xx07)*xx07'wmat7'y ;
 m0[i,7] = a[1,.] ;
endif;


if det(xx08'wmat8*xx08) > epsln ;
 a2= pinv(xx08'wmat8*xx08)*xx08'wmat8'y ;
 m0[i,8] = a2[1,.] ;
endif;

if det(xx09'wmat9*xx09) > epsln ;
 a= pinv(xx09'wmat9*xx09)*xx09'wmat9'y ;
 m0[i,9] = a[1,.] ;
endif;

if det(xx10'wmat10*xx10) > epsln ;
 a= pinv(xx10'wmat10*xx10)*xx10'wmat10'y ;
 m0[i,10] = a[1,.] ;
 endif;

if det(xx11'wmat11*xx11) > epsln ;
 a= pinv(xx11'wmat11*xx11)*xx11'wmat11'y ;
 m0[i,11] = a[1,.] ;
endif;

if det(xx12'wmat12*xx12) > epsln ;
 a= pinv(xx12'wmat12*xx12)*xx12'wmat12'y ;
 m0[i,12] = a[1,.] ;
endif;

if det(xx13'wmat13*xx13) > epsln ;
 a= pinv(xx13'wmat13*xx13)*xx13'wmat13'y ;
 m0[i,13] = a[1,.] ;
endif;
i=i+1;
endo;
R1=(m0[.,1]-y).*(m0[.,1]-y);
R2=(m0[.,2]-y).*(m0[.,2]-y);
R3=(m0[.,3]-y).*(m0[.,3]-y);
R4=(m0[.,4]-y).*(m0[.,4]-y);
R5=(m0[.,5]-y).*(m0[.,5]-y);
R6=(m0[.,6]-y).*(m0[.,6]-y);
R7=(m0[.,7]-y).*(m0[.,7]-y);
R8=(m0[.,8]-y).*(m0[.,8]-y);
R9=(m0[.,9]-y).*(m0[.,9]-y);
R10=(m0[.,10]-y).*(m0[.,10]-y);
R11=(m0[.,11]-y).*(m0[.,11]-y);
R12=(m0[.,12]-y).*(m0[.,12]-y);
R13=(m0[.,13]-y).*(m0[.,13]-y);
GAhat1[k,kc] = 1/T*sumc(R1);
GAhat2[k,kc]= 1/T*sumc(R2);
GAhat3[k,kc] = 1/T*sumc(R3);
GAhat4[k,kc]= 1/T*sumc(R4);
GAhat5[k,kc] = 1/T*sumc(R5);
GAhat6[k,kc]= 1/T*sumc(R6);
GAhat7[k,kc] = 1/T*sumc(R7);
GAhat8[k,kc]= 1/T*sumc(R8);
GAhat9[k,kc] = 1/T*sumc(R9);
GAhat10[k,kc]= 1/T*sumc(R10);
GAhat11[k,kc] = 1/T*sumc(R11);
GAhat12[k,kc]= 1/T*sumc(R12);
GAhat13[k,kc]= 1/T*sumc(R13);
GBhat1[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR1./Gphat[.,1])*1/T;
GBhat2[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR2./Gphat[.,2])*1/T;
GBhat3[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR3./Gphat[.,3])*1/T;
GBhat4[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR4./Gphat[.,4])*1/T;
GBhat5[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR5./Gphat[.,5])*1/T;
GBhat6[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR6./Gphat[.,6])*1/T;
GBhat7[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR7./Gphat[.,7])*1/T;
GBhat8[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR8./Gphat[.,8])*1/T;
GBhat9[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR9./Gphat[.,9])*1/T;
GBhat10[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR10./Gphat[.,10])*1/T;
GBhat11[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR11./Gphat[.,11])*1/T;
GBhat12[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR12./Gphat[.,12])*1/T;
GBhat13[k,kc] =2/(ha6^6)*1/(sqrt(2*pi))^6*1/T*sumc(BR13./Gphat[.,13])*1/T;
GFPE1[k,kc]=GAhat1[k,kc]+GBhat1[k,kc];
GFPE2[k,kc]=GAhat2[k,kc]+GBhat2[k,kc];
GFPE3[k,kc]=GAhat3[k,kc]+GBhat3[k,kc];
GFPE4[k,kc]=GAhat4[k,kc]+GBhat4[k,kc];
GFPE5[k,kc]=GAhat5[k,kc]+GBhat5[k,kc];
GFPE6[k,kc]=GAhat6[k,kc]+GBhat6[k,kc];
GFPE7[k,kc]=GAhat7[k,kc]+GBhat7[k,kc];
GFPE8[k,kc]=GAhat8[k,kc]+GBhat8[k,kc];
GFPE9[k,kc]=GAhat9[k,kc]+GBhat9[k,kc];
GFPE10[k,kc]=GAhat10[k,kc]+GBhat10[k,kc];
GFPE11[k,kc]=GAhat11[k,kc]+GBhat11[k,kc];
GFPE12[k,kc]=GAhat12[k,kc]+GBhat12[k,kc];
GFPE13[k,kc]=GAhat13[k,kc]+GBhat13[k,kc];
kc=kc+1;
endo;
min1=minc(GFPE1[k,.]');
min2=minc(GFPE2[k,.]');
min3=minc(GFPE3[k,.]');
min4=minc(GFPE4[k,.]');
min5=minc(GFPE5[k,.]');
min6=minc(GFPE6[k,.]');
min7=minc(GFPE7[k,.]');
min8=minc(GFPE8[k,.]');
min9=minc(GFPE9[k,.]');
min10=minc(GFPE10[k,.]');
min11=minc(GFPE11[k,.]');
min12=minc(GFPE12[k,.]');
min13=minc(GFPE13[k,.]');
minGFPE=min1~min2~min3~min4~min5~min6~min7~min8~min9~min10~min11~min12~min13;
minGFPE[.,lag_1]=10^10;
minGFPE[.,lag_2]=10^10;
minGFPE[.,lag_3]=10^10;
minGFPE[.,lag_4]=10^10;
minGFPE[.,lag_5]=10^10;
AFPE[k,6]=minc(minGFPE');
lag[k,6]=minindc(minGFPE');
lag_6=lag[k,6];
k=k+1;
endo;
Final_Lag=lag;
/*underfitting correct fitting and overfitting */
minlag=minindc(AFPE');
lags=lag;
i=1;
do until i>itr;
if minlag[i]<6;
 in=6-minlag[i];
 b=minlag[i]+1;
 lags[i,b:6]=zeros(1,in);
endif;
i=i+1;
endo;
in1=lags.==para1;
in2=lags.==para2;
lags=lags+in1*100+in2*100;
/*correct fitting */
n0=minlag.==2;
cc=sumc(lags').>=200;
aa1=(n0+cc).==2;
correct=sumc(aa1)/itr;
/*underfitting */
n1=minlag.==1;
cc=sumc(lags').>=100;
aa2=(n1+cc).==2;
underfit=sumc(aa2)/itr;
/*overfitting */
n3=minlag.>2;
cc=sumc(lags').>=200;
aa3=n3+cc.>=2;
overfit=sumc(aa3)/itr;
FA=underfit~correct~overfit;
/*calculate underfitting, overfitting and correct fitting by FPE with correction term*/
ct1=1+T^(-4/5);
ct2=1+2*T^(-4/6);
ct3=1+3*T^(-4/7);
ct4=1+4*T^(-4/8);
ct5=1+5*T^(-4/9);
ct6=1+6*T^(-4/10);
ct=ct1~ct2~ct3~ct4~ct5~ct6;
CFPE=ct.*AFPE;
/*underfitting correct fitting and overfitting */
minlag=minindc(CFPE');
lags=lag;
i=1;
do until i>itr;
if minlag[i]<6;
 in=6-minlag[i];
 b=minlag[i]+1;
 lags[i,b:6]=zeros(1,in);
endif;
i=i+1;
endo;
in1=lags.==para1;
in2=lags.==para2;
lags=lags+in1*100+in2*100;
/*correct fitting */
n0=minlag.==2;
cc=sumc(lags').>=200;
aa1=(n0+cc).==2;
ccorrect=sumc(aa1)/itr;
/*underfitting */
n1=minlag.==1;
cc=sumc(lags').>=100;
aa2=(n1+cc).==2;
cunderfit=sumc(aa2)/itr;
/*overfitting */
n3=minlag.>2;
cc=sumc(lags').>=200;
aa3=n3+cc.>=2;
coverfit=sumc(aa3)/itr;
CFA=cunderfit~ccorrect~coverfit;
print CFA;
"Total time used in computation:";
print "nonparametric FPE result";
print "T" ;t;
print "lag" ;
final_lag;
print "AFPE" ;
AFPE;
print "CFPE";
CFPE;
print "underfitting,correct fitting and overfitting by FPE";
print underfit correct  overfit;
print "underfitting,correct fitting and overfitting by FPE with correction term";
print  cunderfit ccorrect coverfit;



/*********(END OF PROGRAM)**********/

/**********************************************/
/*             Choice of kernel               */
/**********************************************/
/* (iii) Gaussian kernel */
fn fi(z) = exp(-(z.^2)/2)./sqrt(2*pi) ;

/*
** (i) Epanechnikov kernel
** fn fi(z) = (abs(z).<1)*(3/4).*(ones(T,1)-(z.^2)) ;
**
** (ii) Quartic kernel
** fn fi(z) = (abs(z).<1)*(15/16).*((ones(T,1)-(z.^2)).^2) ;
**
** (iii) Gaussian kernel
** fn fi(z) = exp(-(z.^2)/2)./sqrt(2*pi) ;
*/
/*** Procedures ***/

proc lagn(x,n);
    local y;
    y = shiftr(x', n, (miss(0, 0))');
    retp(y');
endp;

